import React from 'react';
import Modularity from 'modularity-entry';

import PresentCards from '../HigherModules/PresentCards';

import Icon from '@material-ui/core/Icon';

import './price.css'
let Module = Modularity.Module;
let API = new Modularity.Entry.Services.API();

class PricePackage extends Modularity.Module {
	constructor(props) {
		super(props);
		this.state =  {
			products:[],
			lastUpdate:"12"
		}
		this.loadNotifications()
		.then((result) => {
			this.setState({products:result});
			this.forceUpdate();
		})
		
		this.data.onUpdate((v) => {
			console.log("Updated",v)
		});
	}


	loadNotifications(){
		return API.get('/notifications',{
			method:"GET",
			headers:{
				'Content-Type':'application/json'
			}
		})
		.then((data) => {
			console.log(data);
			let products = data.map((item) => {
				let product = {};
				product['id'] = item.SKU;
				product['title'] = item.title;
				product['ΕΜΠΟΡΟΣ'] = item.name;
				product['ΠΡΟΤΕΙΝΟΜΕΝΗ ΤΙΜΗ'] = parseFloat(item.actual_price).toFixed(2);
				product['ΤΙΜΗ ΕΜΠΟΡΟΥ'] = parseFloat(item.price).toFixed(2);
				product['discount'] = Math.ceil(item.discount*100);
				product['link'] = item.link;
				return product;
			});
			return products;
		})
	}


	refreshProd(e){
		window.fetch('/api/crawler/init')
		.then((result) => {
			if(result.status !== 200) {
				alert("Running...")
			} 
			this.forceUpdate();
		})
		.catch((e) => {
			console.log(e);
		})
	}


	render() {
		return(
			<div className="row price_page">
				<div className="col s12">
					<div className="row title">
						<div className="col s9 price_header">Ειδοποιήσεις <Icon onClick={(e) => this.refreshProd(e)} className="renew">autorenew</Icon></div>
						
					</div>
					<PresentCards  data={this.state.products} cardHeader="title" cardType="CardModule" />
					{super.render()}
				</div>
			</div>
			);
				    
	}
}





PricePackage.EditPosition = "center";
PricePackage.Inputs = {
	data:{
		type:Module.Types.Array,
		defaultValue:[
		{
			"id":"#32",
			"title":"Κουρτίνα με Τρέσα 300x270",
			"Trader":"SpitiShop",
			"Actual_Price":"17,80",
			"Reduced_Price":"14,80",	
			"discount":"20%"
		},
		{
			"id":"#32",
			"title":"Κουρτίνα με Τρέσα 300x270",
			"Trader":"SpitiShop",
			"Actual_Price":"17,80",
			"Reduced_Price":"14,80",	
			"discount":"20%"
		},
		{
			"id":"#32",
			"title":"Κουρτίνα με Τρέσα 300x270",
			"Trader":"SpitiShop",
			"Actual_Price":"17,80",
			"Reduced_Price":"14,80",	
			"discount":"20%"
		},
		{
			"id":"#32",
			"title":"Κουρτίνα με Τρέσα 300x270",
			"Trader":"SpitiShop",
			"Actual_Price":"17,80",
			"Reduced_Price":"14,80",	
			"discount":"20%"
		}
		],
		arrType:Module.Types.Object	
	}

}

PricePackage.Outputs = {
	
}

PricePackage.Category = "Das-Home Pages";
export default PricePackage;