import React from 'react';
import Modularity from 'modularity-entry';

import PresentCards from '../HigherModules/PresentCards';
import SearchBar from '../Modules/SearchBar';

import './products.css';
import Icon from '@material-ui/core/Icon';
let Module = Modularity.Module;


let API = new Modularity.Entry.Services.API();
class ProductsPackage extends Modularity.Module{
	constructor(props) {
		super(props);
		this.state =  {
			products:[],
			lastUpdate:"12"
		}

		this.loadProducts()
		.then((products) => {
			this.setState({products:products, allProds: products})
			this.forceUpdate();
		})
		
		this.data.onUpdate((v) => {
			console.log("Updated",v)
		});
	}

	search(term) {
		let allProds = this.state.allProds;
		let temp = allProds.filter((item) => item.title && item.title.includes(term));
		this.setState({
			products: temp
		})
	}

	refresh(id) {
		let num = parseInt(id.slice(1));
		console.log('/crawler/product/'+ num);
		return API.get('/crawler/product/'+ num)
		.then((res) => this.loadProducts())
		.then((products) => this.setState({products, allProds: products}));
	}

	loadProducts(){
		return API.get('skus?perPage=48',{
			method:"GET",
			headers:{
				'Content-Type':'application/json'
			}
		})
		.then((data) => {
			let products = data.map((item) => {
				let product = {};
				product['id'] = "#"+item.id;
				product['title'] = item.title;
				product['ΠΡΟΤΕΙΝΟΜΕΝΗ ΤΙΜΗ'] = parseFloat(item.suggested_price).toFixed(2);
				product['ΠΑΡΑΒΙΑΣΕΙΣ'] = item.paraviaseis;
				product['link'] = item.link;
				return product;
			})
			return products;
		})
	}

	render() {
		return(
			<div className="row products_page">
				<div className="col s12">
					<div className="row title">
						<div className="col s9 price_header">Προϊόντα</div>
						
					</div>
					<div className="row SearchBar">
						<div className="col">
						<SearchBar onSearch={(term) => this.search(term)}/>
						</div>
					</div>
					<PresentCards  data={this.state.products} cardHeader="title" linkText={'Δείτε όλες τις καταχωρήσεις'} cardType="CardProd" onRefresh={(id) => this.refresh(id)}/>
				</div>
				{super.render()}
			</div>
			);
				    
	}
}





ProductsPackage.EditPosition = "center";
ProductsPackage.Inputs = {
	data:{
		type:Module.Types.Array,
		defaultValue:[
		{
			"id":"#32",
			"title":"Κουρτίνα με Τρέσα 300x270",
			"Προτεινόμενη Τιμή":"SpitiShop",
			"Παραβιάσεις":"17,80",	
			"link":"/category_link"
		},
		{
			"id":"#32",
			"title":"Κουρτίνα με Τρέσα 300x270",
			"Προτεινόμενη Τιμή":"SpitiShop",
			"Παραβιάσεις":"17,80",	
			"link":"/category_link"
		},
		{
			"id":"#32",
			"title":"Κουρτίνα με Τρέσα 300x270",
			"Προτεινόμενη Τιμή":"SpitiShop",
			"Παραβιάσεις":"17,80",	
			"link":"/category_link"
		},
		{
			"id":"#32",
			"title":"Κουρτίνα με Τρέσα 300x270",
			"Προτεινόμενη Τιμή":"SpitiShop",
			"Παραβιάσεις":"17,80",	
			"link":"/category_link"
		}
		],
		arrType:Module.Types.Object	
	}

}

ProductsPackage.Outputs = {
	
}

ProductsPackage.Category = "Das-Home Pages";
export default ProductsPackage;